==> nextcloud-26.0.11p1.tgz: nextcloud/apps/systemtags/l10n/lt_LT.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sistema pridėjo sistemos žymę %1$s",
    "Added system tag {systemtag}" : "Pridėta sistemos žymė {systemtag}",
    "Added system tag %1$s" : "Pridėta sistemos žymė %1$s",
    "%1$s added system tag %2$s" : "%1$s pridėjo sistemos žymę %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridėjo sistemos žymę {systemtag}",
    "System tag %1$s removed by the system" : "Sistema pašalino sistemos žymę %1$s",
    "Removed system tag {systemtag}" : "Pašalinta sistemos žymė {systemtag}",
    "Removed system tag %1$s" : "Pašalinta sistemos žymė %1$s",
    "%1$s removed system tag %2$s" : "%1$s pašalino sistemos žymę %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} pašalino sistemos žymę {systemtag}",
    "You created system tag %1$s" : "Jūs sukūrėte sistemos žymę %1$s",
    "You created system tag {systemtag}" : "Jūs sukūrėte sistemos žymę {systemtag}",
    "%1$s created system tag %2$s" : "%1$s sukūrė sistemos žymę %2$s",
    "{actor} created system tag {systemtag}" : "{actor} sukūrė sistemos žymę {systemtag}",
    "You deleted system tag %1$s" : "Jūs ištrynėte sistemos žymę %1$s",
    "You deleted system tag {systemtag}" : "Jūs ištrynėte sistemos žymę {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ištrynė sistemos žymę %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ištrynė sistemos žymę {systemtag}",
    "You updated system tag %2$s to %1$s" : "Jūs atnaujinote sistemos žymę %2$s į %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atnaujinote sistemos žymę {oldsystemtag} į {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atnaujino sistemos žymę %3$s į %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atnaujino sistemos žymę {oldsystemtag} į {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Jūs pridėjote sistemos žymę %2$s prie %1$s",
    "You added system tag {systemtag} to {file}" : "Jūs pridėjote sistemos žymę {systemtag} prie {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s pridėjo sistemos žymę %3$s prie %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pridėjo sistemos žymę {systemtag} prie {file}",
    "You removed system tag %2$s from %1$s" : "Jūs pašalinote sistemos žymę %2$s nuo %1$s",
    "You removed system tag {systemtag} from {file}" : "Jūs pašalinote sistemos žymę {systemtag} nuo {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s pašalino sistemos žymę %3$s nuo %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} pašalino sistemos žymę {systemtag} nuo {file}",
    "%s (restricted)" : "%s (apribotas)",
    "%s (invisible)" : "%s (nematomas)",
    "<strong>System tags</strong> for a file have been modified" : "Modifikuotos failo <strong>sistemos žymės</strong>",
    "Tags" : "Žymės",
    "All tagged %s …" : "Visi pažymėti %s ...",
    "tagged %s" : "pažymėta %s",
    "Collaborative tags" : "Bendradarbiavimo žymės",
    "Create" : "Sukurti",
    "Update" : "Atnaujinti",
    "Delete" : "Ištrinti",
    "Reset" : "Atstatyti",
    "Loading …" : "Įkeliama…",
    "Public" : "Vieša",
    "Restricted" : "Apribota",
    "Invisible" : "Nematoma",
    "Failed to create tag" : "Nepavyko įkelti žymios",
    "Failed to delete tag" : "Nepavyko pervadinti žymės",
    "Failed to load tags" : "Nepavyko įkelti žymių",
    "Failed to select tag" : "Nepavyko parinkti žymios",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Bendradarbiavimo žymės yra prieinamos visiems naudotojams. Apribotos žymės yra matomos naudotojams, tačiau naudotojai negali jų priskirinėti. Nematomos žymės yra vidiniam naudojimui, nes naudotojai negali jų nei matyti, nei priskirinėti.",
    "This file has the tag {tag}" : "Šis failas turi žymą {tag}",
    "No tags found" : "Nerasta jokių žymių",
    "Failed to load last used tags" : "Nepavyko įkelti paskutinių naudotų žymų",
    "No files in here" : "Čia failų nėra",
    "No entries found in this folder" : "Šiame aplanke nerasta jokių įrašų",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeista",
    "Tag name is empty" : "Žymės pavadinimas yra tuščias",
    "Select tag …" : "Pasirinkite žymę…",
    "Tagged files" : "Pažymėti failai",
    "Select tags to filter by" : "Pasirinkite žymes, pagal kurias filtruoti",
    "Please select tags to filter by" : "Pasirinkite žymes, pagal kurias filtruoti",
    "No files found for the selected tags" : "Pasirinktai žymei, nerasti jokie failai.",
    "Create a new tag" : "Sukurti naują žymę"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-29.0.10.tgz: nextcloud/apps/systemtags/l10n/lt_LT.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sistema pridėjo sistemos žymę %1$s",
    "Added system tag {systemtag}" : "Pridėta sistemos žymė {systemtag}",
    "Added system tag %1$s" : "Pridėta sistemos žymė %1$s",
    "%1$s added system tag %2$s" : "%1$s pridėjo sistemos žymę %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridėjo sistemos žymę {systemtag}",
    "System tag %1$s removed by the system" : "Sistema pašalino sistemos žymę %1$s",
    "Removed system tag {systemtag}" : "Pašalinta sistemos žymė {systemtag}",
    "Removed system tag %1$s" : "Pašalinta sistemos žymė %1$s",
    "%1$s removed system tag %2$s" : "%1$s pašalino sistemos žymę %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} pašalino sistemos žymę {systemtag}",
    "You created system tag %1$s" : "Jūs sukūrėte sistemos žymę %1$s",
    "You created system tag {systemtag}" : "Jūs sukūrėte sistemos žymę {systemtag}",
    "%1$s created system tag %2$s" : "%1$s sukūrė sistemos žymę %2$s",
    "{actor} created system tag {systemtag}" : "{actor} sukūrė sistemos žymę {systemtag}",
    "You deleted system tag %1$s" : "Jūs ištrynėte sistemos žymę %1$s",
    "You deleted system tag {systemtag}" : "Jūs ištrynėte sistemos žymę {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ištrynė sistemos žymę %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ištrynė sistemos žymę {systemtag}",
    "You updated system tag %2$s to %1$s" : "Jūs atnaujinote sistemos žymę %2$s į %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atnaujinote sistemos žymę {oldsystemtag} į {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atnaujino sistemos žymę %3$s į %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atnaujino sistemos žymę {oldsystemtag} į {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Jūs pridėjote sistemos žymę %2$s prie %1$s",
    "You added system tag {systemtag} to {file}" : "Jūs pridėjote sistemos žymę {systemtag} prie {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s pridėjo sistemos žymę %3$s prie %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pridėjo sistemos žymę {systemtag} prie {file}",
    "You removed system tag %2$s from %1$s" : "Jūs pašalinote sistemos žymę %2$s nuo %1$s",
    "You removed system tag {systemtag} from {file}" : "Jūs pašalinote sistemos žymę {systemtag} nuo {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s pašalino sistemos žymę %3$s nuo %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} pašalino sistemos žymę {systemtag} nuo {file}",
    "%s (restricted)" : "%s (apribotas)",
    "%s (invisible)" : "%s (nematomas)",
    "<strong>System tags</strong> for a file have been modified" : "Modifikuotos failo <strong>sistemos žymės</strong>",
    "Files" : "Failai",
    "Tags" : "Žymės",
    "All tagged %s …" : "Visi pažymėti %s ...",
    "tagged %s" : "pažymėta %s",
    "Collaborative tags" : "Bendradarbiavimo žymės",
    "Create or edit tags" : "Sukurti ar taisyti žymes",
    "Collaborative tags …" : "Bendradarbiavimo žymės…",
    "Tag name" : "Žymės pavadinimas",
    "Create" : "Sukurti",
    "Update" : "Atnaujinti",
    "Delete" : "Ištrinti",
    "Reset" : "Atstatyti",
    "Loading …" : "Įkeliama…",
    "Public" : "Vieša",
    "Restricted" : "Apribota",
    "Invisible" : "Nematoma",
    "Failed to create tag" : "Nepavyko sukurti žymės",
    "Updated tag" : "Atnaujinta žymė",
    "Failed to update tag" : "Nepavyko atnaujinti žymės",
    "Deleted tag" : "Ištrinta žymė",
    "Failed to delete tag" : "Nepavyko ištrinti žymės",
    "Manage tags" : "Tvarkyti žymes",
    "Applying tags changes…" : "Taikomi pakeitimai žymėms…",
    "Search or create tag" : "Ieškoti ar sukurti žymę",
    "Create new tag" : "Sukurti naują žymę",
    "Cancel" : "Atsisakyti",
    "Apply changes" : "Taikyti pakeitimus",
    "Failed to apply tags changes" : "Nepavyko pritaikyti žymių pakeitimų",
    "Loading collaborative tags …" : "Įkeliamos bendradarbiavimo žymės…",
    "Search or create collaborative tags" : "Ieškoti ar sukurti bendradarbiavimo žymes",
    "Failed to load tags" : "Nepavyko įkelti žymių",
    "Failed to load selected tags" : "Nepavyko įkelti pasirinktų žymių",
    "Failed to select tag" : "Nepavyko pasirinkti žymės",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Bendradarbiavimo žymės yra prieinamos visiems naudotojams. Apribotos žymės yra matomos naudotojams, tačiau naudotojai negali jų priskirinėti. Nematomos žymės yra vidiniam naudojimui, nes naudotojai negali jų nei matyti, nei priskirinėti.",
    "No tags found" : "Nerasta jokių žymių",
    "Tags you have created will show up here." : "Čia bus rodomos jūsų sukurtos žymės.",
    "Failed to load tag" : "Nepavyko įkelti žymės",
    "Failed to load last used tags" : "Nepavyko įkelti paskutinių naudotų žymų",
    "This file has the tag {tag}" : "Šis failas turi žymą {tag}",
    "No files in here" : "Čia failų nėra",
    "No entries found in this folder" : "Šiame aplanke nerasta jokių įrašų",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeista"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
